@@ -1,10 +1,10 @@
 ##----------------------------------------------------------------------------
 ## Module Generic - ~/lib/Module/Generic/Array.pm
-## Version v2.2.0
-## Copyright(c) 2024 DEGUEST Pte. Ltd.
+## Version v2.2.1
+## Copyright(c) 2025 DEGUEST Pte. Ltd.
 ## Author: Jacques Deguest <jack@deguest.jp>
 ## Created 2021/03/20
-## Modified 2025/04/19
+## Modified 2025/04/20
 ## All rights reserved
 ## 
 ## This program is free software; you can redistribute  it  and/or  modify  it
@@ -38,12 +38,14 @@ BEGIN
     if( HAS_THREADS )
     {
         require threads;
-        import threads;
+        require threads::shared;
+        threads->import();
+        threads::shared->import();
     }
     $DEBUG  = 0;
     $ERRORS = {};
     $RETURN = {};
-    our $VERSION = 'v2.2.0';
+    our $VERSION = 'v2.2.1';
 };
 
 use v5.26.1;
@@ -322,7 +324,6 @@ sub error
         $o = $ex_class->new( $args );
         if( HAS_THREADS )
         {
-            require threads::shared;
             lock( $ERROR );
             $ERRORS->{ $addr } = $ERROR = $o;
         }
