@@ -1,10 +1,10 @@
 ##----------------------------------------------------------------------------
 ## Module Generic - ~/lib/Module/Generic/Boolean.pm
-## Version v1.2.0
-## Copyright(c) 2022 DEGUEST Pte. Ltd.
+## Version v1.2.1
+## Copyright(c) 2025 DEGUEST Pte. Ltd.
 ## Author: Jacques Deguest <jack@deguest.jp>
 ## Created 2021/03/20
-## Modified 2025/04/19
+## Modified 2025/04/20
 ## All rights reserved
 ## 
 ## This program is free software; you can redistribute  it  and/or  modify  it
@@ -28,9 +28,11 @@ BEGIN
     if( HAS_THREADS )
     {
         require threads;
-        import threads;
+        require threads::shared;
+        threads->import();
+        threads::shared->import();
     }
-    our( $VERSION ) = 'v1.2.0';
+    our( $VERSION ) = 'v1.2.1';
 };
 
 use v5.26.1;
