@@ -1,10 +1,10 @@
 ##----------------------------------------------------------------------------
 ## Module Generic - ~/lib/Module/Generic/File/Cache.pm
-## Version v0.2.8
-## Copyright(c) 2024 DEGUEST Pte. Ltd.
+## Version v0.2.9
+## Copyright(c) 2025 DEGUEST Pte. Ltd.
 ## Author: Jacques Deguest <jack@deguest.jp>
 ## Created 2022/03/16
-## Modified 2025/03/12
+## Modified 2025/04/20
 ## All rights reserved
 ## 
 ## This program is free software; you can redistribute  it  and/or  modify  it
@@ -23,7 +23,9 @@ BEGIN
     if( HAS_THREADS )
     {
         require threads;
-        import threads;
+        require threads::shared;
+        threads->import();
+        threads::shared->import();
         our $CACHE_REPO;
         our $CACHE_TO_OBJECT;
     }
@@ -45,7 +47,7 @@ BEGIN
     $CACHE_REPO = [];
     $CACHE_TO_OBJECT = {};
     $DEBUG = 0;
-    our $VERSION = 'v0.2.8';
+    our $VERSION = 'v0.2.9';
 };
 
 use v5.26.1;
@@ -288,7 +290,6 @@ sub open
     $new->{_cache_file} = $fo;
     if( IN_THREAD )
     {
-        require threads::shared;
         lock( $CACHE_REPO );
         lock( $CACHE_TO_OBJECT );
         push( @$CACHE_REPO, $new );
@@ -426,7 +427,6 @@ sub remove
     {
         if( IN_THREAD )
         {
-            require threads::shared;
             lock( $CACHE_REPO );
             OBJECT: for( my $i = 0; $i < scalar( @$CACHE_REPO ); $i++ )
             {
@@ -919,7 +919,6 @@ END
 
     if( IN_THREAD )
     {
-        require threads::shared;
         lock( $CACHE_REPO );
     }
 
@@ -1024,7 +1023,7 @@ Module::Generic::File::Cache - File-based Cache
 
 =head1 VERSION
 
-    v0.2.8
+    v0.2.9
 
 =head1 DESCRIPTION
 
