@@ -1,10 +1,10 @@
 ##----------------------------------------------------------------------------
 ## Module Generic - ~/lib/Module/Generic/Iterator.pm
-## Version v1.2.0
-## Copyright(c) 2022 DEGUEST Pte. Ltd.
+## Version v1.2.1
+## Copyright(c) 2025 DEGUEST Pte. Ltd.
 ## Author: Jacques Deguest <jack@deguest.jp>
 ## Created 2021/03/20
-## Modified 2025/04/19
+## Modified 2025/04/20
 ## All rights reserved
 ## 
 ## This program is free software; you can redistribute  it  and/or  modify  it
@@ -23,12 +23,14 @@ BEGIN
     if( HAS_THREADS )
     {
         require threads;
-        import threads;
+        require threads::shared;
+        threads->import();
+        threads::shared->import();
     }
     use Module::Generic::Array;
     use Scalar::Util ();
     use Want;
-    our( $VERSION ) = 'v1.2.0';
+    our( $VERSION ) = 'v1.2.1';
 };
 
 use v5.12.0;
@@ -129,7 +131,6 @@ sub next
         return if( $self->eof );
         if( HAS_THREADS )
         {
-            require threads::shared;
             lock( $self );
             $self->pos++;
         }
@@ -182,7 +183,6 @@ sub prev
     {
         if( HAS_THREADS )
         {
-            require threads::shared;
             lock( $self );
             $self->pos-- if( $self->pos > 0 );
         }
